@@ -522,9 +522,9 @@ class VCSRepoNotifHook(hook.Hook):
         def callback(msg):
             self.debug('received notification: %s', ' '.join(msg))
             msg = msg[-1]
-            with self.internal_session() as session:
+            with self.repo.internal_session() as session:
                 for suffix in ('', '/'):
-                    rset = sessions.execute('Any R WHERE R source_url U, '
+                    rset = session.execute('Any R WHERE R source_url U, '
                                             'R source_url LIKE %(u)s',
                                             {'u': '%/'+msg+suffix})
                     if rset:
