@@ -45,7 +45,7 @@ class SVNRepository(repo.VCSRepository):
         repos.open(fspath) # throwaway, just check it's a valid svn repository
         return fspath
 
-    def import_content(self, repoentity, commitevery=10):
+    def import_content(self, repoentity, commitevery=1000):
         """import content from the subversion repository
 
         NOTE: server side only method
@@ -213,7 +213,7 @@ class SVNImporter(delta.Editor):
         bridge.set_at_revision(self.session, self.reveid)
 
     def base_rev_content(self):
-        revdata = {'revision': self.rev}
+        revdata = {'revision': self.rev, 'hidden': False}
         author = fs.revision_prop(self.fsrep, self.rev,
                                   core.SVN_PROP_REVISION_AUTHOR)
         revdata['author'] = unicode(author, self.encoding, 'replace')
@@ -234,6 +234,7 @@ class SVNImporter(delta.Editor):
                               'X from_repository R, R eid %(r)s',
                               {'rev': self.rev - 1, 'r': self.repoeid})
         revdata['parents'] = parent and parent[0]
+        revdata['precursors'] = ()
         return revdata
 
 #     def rev_content(self, path):
