@@ -25,7 +25,11 @@ class RevisionExportService(Service):
                                        'unified': 5,
                                        })
         hdrepo = bridge.repository_handler(repo)
+        hgrepo = hdrepo.hgrepo()
+        if nodeid not in hgrepo:
+            # local cache miss
+            return None
         revs = [nodeid]
         output = Binary()
-        cmdutil.export(hdrepo.hgrepo(), revs, fp=output, opts=diffopts)
+        cmdutil.export(hgrepo, revs, fp=output, opts=diffopts)
         return output.getvalue()
