@@ -8,7 +8,7 @@ __docformat__ = "restructuredtext en"
 _ = unicode
 
 from cubicweb.predicates import (one_line_rset, is_instance, rql_condition,
-                                 score_entity, match_user_groups)
+                                 score_entity, match_user_groups, anonymous_user)
 from cubicweb.web.action import Action
 from cubicweb.web.views.actions import CopyAction
 
@@ -136,6 +136,7 @@ CopyAction.__select__ = CopyAction.__select__ & ~is_instance(
 # revisions of versioned files
 class VFAddRevisionAction(VFAction):
     __regid__ = 'addrevision'
+    __select__ = VFAction.__select__ & ~anonymous_user()
 
     title = _('actions_addrevision')
     order = 111
@@ -151,6 +152,7 @@ class VFAddRevisionAction(VFAction):
 
 class VFPutUpdateAction(VFAction):
     __regid__ ='vfnewrevaction'
+    __select__ = VFAction.__select__ & ~anonymous_user()
 
     title = _('upload revision')
 
@@ -160,8 +162,9 @@ class VFPutUpdateAction(VFAction):
 
 class VFRmAction(VFAction):
     __regid__ = 'vcsrmaction'
-    __select__ = VFAction.__select__ & \
-                 score_entity(lambda x: not x.deleted_in_branch())
+    __select__ = (VFAction.__select__ &
+                  ~anonymous_user() &
+                  score_entity(lambda x: not x.deleted_in_branch()))
 
     title = _('mark this file as deleted in the repository')
     category = 'moreactions'
